pub struct A2aPeerConfig {
pub instance_id: String,
pub agent_id: String,
pub endpoint: String,
pub bearer_token: SecretString,
}Expand description
One exact remote UAR agent binding. Reusing a token for several agents is explicit: each endpoint still needs its own entry and artifact dependency.
Fields
instance_id: Stringagent_id: Stringendpoint: Stringbearer_token: SecretStringTrait Implementations
Sourceimpl Clone for A2aPeerConfig
impl Clone for A2aPeerConfig
Sourcefn clone(&self) -> A2aPeerConfig
fn clone(&self) -> A2aPeerConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for A2aPeerConfig
impl Debug for A2aPeerConfig
Sourceimpl<'de> Deserialize<'de> for A2aPeerConfig
impl<'de> Deserialize<'de> for A2aPeerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for A2aPeerConfig
impl JsonSchema for A2aPeerConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for A2aPeerConfig
impl RefUnwindSafe for A2aPeerConfig
impl Send for A2aPeerConfig
impl Sync for A2aPeerConfig
impl Unpin for A2aPeerConfig
impl UnsafeUnpin for A2aPeerConfig
impl UnwindSafe for A2aPeerConfig