pub fn dual_sse_event(evt: &NormalizedEvent, request_id: &str) -> StringExpand description
Emit both normalized and AG-UI events for a single NormalizedEvent.
This is useful for clients that support either protocol.
pub fn dual_sse_event(evt: &NormalizedEvent, request_id: &str) -> StringEmit both normalized and AG-UI events for a single NormalizedEvent.
This is useful for clients that support either protocol.