pub async fn list(registry: &Arc<A2uiRegistry>) -> Vec<ArtifactSchema>Expand description
Every artifact schema this runtime can render, sorted by id.
pub async fn list(registry: &Arc<A2uiRegistry>) -> Vec<ArtifactSchema>Every artifact schema this runtime can render, sorted by id.