pub fn default_agent() -> AgentArtifactExpand description
Returns the default agent artifact used when no specific agent is requested.
pub fn default_agent() -> AgentArtifactReturns the default agent artifact used when no specific agent is requested.