compare

Function compare 

pub fn compare(
    current: &ScoreSummary,
    baseline: &ScoreSummary,
    threshold: f32,
) -> RegressionReport
Compare a current summary to a baseline. A scorer regresses when its mean drops below the baseline by more than threshold. With no baseline entry for a scorer, it is not a regression (a run can establish a baseline).