pub fn scope_requires_auth(scope: &MemoryScope) -> boolExpand description
Check whether a given scope requires a valid user identity.
pub fn scope_requires_auth(scope: &MemoryScope) -> boolCheck whether a given scope requires a valid user identity.