pub fn validate_final_count(
plan: &BudgetPlan,
final_request: &CountedTokens,
) -> BudgetOutcomeExpand description
Recount the complete final serialization and prove it fits the plan.
pub fn validate_final_count(
plan: &BudgetPlan,
final_request: &CountedTokens,
) -> BudgetOutcomeRecount the complete final serialization and prove it fits the plan.