pub struct ToolNode { /* private fields */ }Expand description
A graph node that calls a named MCP tool and stores the result in state.
State keys
- input:
args_key(default"_tool_args") — JSON object with tool arguments. - output:
output_key(default"_tool_result") — raw JSON string result.
Implementations
Sourceimpl ToolNode
impl ToolNode
Sourcepub fn new(id: impl Into<String>, tool_name: impl Into<String>) -> Self
pub fn new(id: impl Into<String>, tool_name: impl Into<String>) -> Self
Create a tool node with the given ID and tool name.
Sourcepub fn with_args_key(self, key: impl Into<String>) -> Self
pub fn with_args_key(self, key: impl Into<String>) -> Self
Override the state key used to read arguments from.
Sourcepub fn with_output_key(self, key: impl Into<String>) -> Self
pub fn with_output_key(self, key: impl Into<String>) -> Self
Override the state key used to write the result to.