pub fn render_with_options(
fragments: &[PromptFragment],
options: RenderOptions,
) -> StringExpand description
Render fragments with stable structure adapted to the resolved model family.
pub fn render_with_options(
fragments: &[PromptFragment],
options: RenderOptions,
) -> StringRender fragments with stable structure adapted to the resolved model family.