pub fn render_with_template(
fragments: &[PromptFragment],
profile: &PromptTemplateProfile,
) -> Result<String, PromptTemplateError>Expand description
Validate and render through one resolved, versioned template profile.
pub fn render_with_template(
fragments: &[PromptFragment],
profile: &PromptTemplateProfile,
) -> Result<String, PromptTemplateError>Validate and render through one resolved, versioned template profile.