pub enum NormalizedEvent {
Show 16 variants
StreamStart {
request_id: String,
},
MessageDelta {
text: String,
},
ThinkingDelta {
text: String,
},
ReasoningDelta {
text: String,
},
CitationAdded(Citation),
MemoryUpdate {
key: String,
value: String,
operation: String,
},
SkillActivation {
name: String,
status: String,
},
Custom {
source: String,
event_name: String,
payload: Value,
},
ToolCallDelta {
call_index: usize,
id: Option<String>,
name: Option<String>,
arguments_delta: Option<String>,
},
ToolCallComplete {
call_index: usize,
id: String,
name: String,
arguments_json: String,
},
ToolResult {
id: String,
name: String,
content: String,
success: bool,
},
SandboxOutput {
stream: String,
data: String,
},
Error {
message: String,
code: Option<String>,
},
Usage {
prompt_tokens: u32,
completion_tokens: u32,
total_tokens: u32,
cached_tokens: Option<u32>,
cache_creation_tokens: Option<u32>,
},
RuntimeStep {
step: u32,
kind: RuntimeStepKind,
},
Done,
}Expand description
Normalized streaming events emitted by the LLM orchestrator.
These events provide a unified interface for the client UI regardless of which LLM protocol is used (Chat Completions, Responses API, etc.).
Variants
StreamStart
Indicates the start of a new streaming response.
MessageDelta
Incremental text delta from the assistant’s response.
ThinkingDelta
Incremental thinking/internal reasoning delta (for models that expose this).
ReasoningDelta
Incremental reasoning delta (chain-of-thought output).
CitationAdded(Citation)
A citation/source reference was added.
MemoryUpdate
Memory/context update from the model.
Fields
SkillActivation
A skill or skill-like provider capability was activated.
UAR proper owns real skill routing/execution. This lower-level event is for external/local drivers that need to preserve provider-emitted skill activation chunks without flattening them into assistant prose.
Fields
Custom
Provider-specific semantic event that should remain inspectable.
Fields
ToolCallDelta
Incremental tool call delta (streaming tool call assembly).
Fields
ToolCallComplete
Tool call is fully assembled and ready for execution.
Fields
ToolResult
Result from executing a tool.
Fields
SandboxOutput
Real-time output from a sandboxed code execution.
Error
An error occurred during streaming.
Fields
Usage
Token usage information from the API.
Fields
RuntimeStep
A tool-loop iteration boundary — per-step run progress. Emitted at the start and end of each orchestrator iteration so the Runtime Console can show step progress.
Fields
kind: RuntimeStepKindWhether the step is beginning or ending.
Done
Stream has completed successfully.