pub fn build_response_router() -> Router<A2uiApiState>Expand description
Build the artifact-response router (mounted at /api/uar/runs).
This is separate from the schema router because it shares the path prefix with the main runs API.
pub fn build_response_router() -> Router<A2uiApiState>Build the artifact-response router (mounted at /api/uar/runs).
This is separate from the schema router because it shares the path prefix with the main runs API.