pub fn validate(
validator: &Validator,
arguments_json: &str,
) -> Result<Value, InvalidArguments>Expand description
Parse raw model arguments and validate the resulting JSON value.
Errors
Returns InvalidArguments for either malformed JSON or a schema
violation. The caller returns this error to the model and must not execute
the tool.